==> itk-4.13.1-py36_0.tar.bz2: Lib/site-packages/itk/Configuration/ITKConvolutionConfig.py <==
depends = ('ITKPyBase', 'ITKThresholding', 'ITKImageIntensity', 'ITKFFT', )
templates = (
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterISS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterISS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterISS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterISS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
)

==> itk-5.0.0-py37_1.tar.bz2: Lib/site-packages/itk/Configuration/ITKConvolutionConfig.py <==
depends = ('ITKPyBase', 'ITKThresholding', 'ITKImageIntensity', 'ITKFFT', )
templates = (
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ConvolutionImageFilterBase', 'itk::ConvolutionImageFilterBase', 'itkConvolutionImageFilterBaseIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ConvolutionImageFilter', 'itk::ConvolutionImageFilter', 'itkConvolutionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('FFTConvolutionImageFilter', 'itk::FFTConvolutionImageFilter', 'itkFFTConvolutionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterISS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterISS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('FFTNormalizedCorrelationImageFilter', 'itk::FFTNormalizedCorrelationImageFilter', 'itkFFTNormalizedCorrelationImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterISS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterISS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
)
snake_case_functions = ('fft_normalized_correlation_image_filter', 'masked_fft_normalized_correlation_image_filter', 'convolution_image_filter', 'fft_convolution_image_filter', 'convolution_image_filter_base', )
